@@ -8,13 +8,18 @@ library(proxy)
 proxies = pr_DB$get_entry_names()
 
 ## remove special cases
-proxies = setdiff(proxies, c("Mahalanobis", "Minkowski", "Stiles"))
+proxies = setdiff(proxies, c("Mahalanobis", "Minkowski", "Stiles", "Levenshtein"))
 
 ## create test data
 x = matrix(1:100, 10)
 
-## test function: checks if dist(x) == dist(x,x) for all measures
-prtest <- function(...) all(as.matrix(dist(x, ...)) == dist(x, x, ...))
+## test function: checks if dist(x) == dist(x,x) for all measures,
+## and if diag(dist(x, x)) == diag(x, x, pairwise = TRUE)
+prtest <- function(...) {
+    CD <- dist(x, x, ...)
+    all(as.matrix(dist(x, ...)) == CD) &&
+      all(diag(CD) == dist(x, x, pairwise = TRUE, ...))
+}
 
 ## loop over all measures (except special cases)
 for (i in proxies)
@@ -42,3 +47,13 @@ for (i in proxies)
     {cat(i); prtest(i); cat(": OK.\n")}
 for (j in c(0, 0.5, 1, 2, 3, Inf))
     {cat("p =", j); prtest(i = "Minkowski", p = j); cat(": OK.\n")}
+
+## Levenshtein distance
+s <- c("A", "quick", "brown", "fox", "jumps", "over", "the", "lazy", "dog")
+all(as.matrix(dist(s, "Levenshtein")) == dist(s, s, "Levenshtein"))
+
+## Test auto-conversion
+x = iris[,-5]
+prtest()
+
+
